
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#include "mbim-errors.h"
#include "mbim-error-types.h"
/* enumerations from "../libmbim/src/libmbim-glib/mbim-errors.h" */
static const GEnumValue mbim_core_error_values[] = {
    { MBIM_CORE_ERROR_FAILED, "MBIM_CORE_ERROR_FAILED", "Failed" },
    { MBIM_CORE_ERROR_WRONG_STATE, "MBIM_CORE_ERROR_WRONG_STATE", "WrongState" },
    { MBIM_CORE_ERROR_TIMEOUT, "MBIM_CORE_ERROR_TIMEOUT", "Timeout" },
    { MBIM_CORE_ERROR_INVALID_ARGS, "MBIM_CORE_ERROR_INVALID_ARGS", "InvalidArgs" },
    { MBIM_CORE_ERROR_INVALID_MESSAGE, "MBIM_CORE_ERROR_INVALID_MESSAGE", "InvalidMessage" },
    { MBIM_CORE_ERROR_UNSUPPORTED, "MBIM_CORE_ERROR_UNSUPPORTED", "Unsupported" },
    { MBIM_CORE_ERROR_ABORTED, "MBIM_CORE_ERROR_ABORTED", "Aborted" },
    { MBIM_CORE_ERROR_UNKNOWN_STATE, "MBIM_CORE_ERROR_UNKNOWN_STATE", "UnknownState" },
    { MBIM_CORE_ERROR_INCOMPLETE_MESSAGE, "MBIM_CORE_ERROR_INCOMPLETE_MESSAGE", "IncompleteMessage" },
    { 0, NULL, NULL }
};

/* mbim_core_error_quark() implemented in mbim-errors-quarks.c */

GType
mbim_core_error_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MbimCoreError"),
                                      mbim_core_error_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

/* Enum-specific method to get the value as a string.
 * We get the nick of the GEnumValue. Note that this will be
 * valid even if the GEnumClass is not referenced anywhere. */
/**
 * mbim_core_error_get_string:
 * @val: a MbimCoreError.
 *
 * Gets the nickname string for the #MbimCoreError specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *
mbim_core_error_get_string (MbimCoreError val)
{
    guint i;

    for (i = 0; mbim_core_error_values[i].value_nick; i++) {
        if ((gint)val == mbim_core_error_values[i].value)
            return mbim_core_error_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mbim_protocol_error_values[] = {
    { MBIM_PROTOCOL_ERROR_INVALID, "MBIM_PROTOCOL_ERROR_INVALID", "Invalid" },
    { MBIM_PROTOCOL_ERROR_TIMEOUT_FRAGMENT, "MBIM_PROTOCOL_ERROR_TIMEOUT_FRAGMENT", "TimeoutFragment" },
    { MBIM_PROTOCOL_ERROR_FRAGMENT_OUT_OF_SEQUENCE, "MBIM_PROTOCOL_ERROR_FRAGMENT_OUT_OF_SEQUENCE", "FragmentOutOfSequence" },
    { MBIM_PROTOCOL_ERROR_LENGTH_MISMATCH, "MBIM_PROTOCOL_ERROR_LENGTH_MISMATCH", "LengthMismatch" },
    { MBIM_PROTOCOL_ERROR_DUPLICATED_TID, "MBIM_PROTOCOL_ERROR_DUPLICATED_TID", "DuplicatedTid" },
    { MBIM_PROTOCOL_ERROR_NOT_OPENED, "MBIM_PROTOCOL_ERROR_NOT_OPENED", "NotOpened" },
    { MBIM_PROTOCOL_ERROR_UNKNOWN, "MBIM_PROTOCOL_ERROR_UNKNOWN", "Unknown" },
    { MBIM_PROTOCOL_ERROR_CANCEL, "MBIM_PROTOCOL_ERROR_CANCEL", "Cancel" },
    { MBIM_PROTOCOL_ERROR_MAX_TRANSFER, "MBIM_PROTOCOL_ERROR_MAX_TRANSFER", "MaxTransfer" },
    { 0, NULL, NULL }
};

/* mbim_protocol_error_quark() implemented in mbim-errors-quarks.c */

GType
mbim_protocol_error_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MbimProtocolError"),
                                      mbim_protocol_error_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

/* Enum-specific method to get the value as a string.
 * We get the nick of the GEnumValue. Note that this will be
 * valid even if the GEnumClass is not referenced anywhere. */
/**
 * mbim_protocol_error_get_string:
 * @val: a MbimProtocolError.
 *
 * Gets the nickname string for the #MbimProtocolError specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *
mbim_protocol_error_get_string (MbimProtocolError val)
{
    guint i;

    for (i = 0; mbim_protocol_error_values[i].value_nick; i++) {
        if ((gint)val == mbim_protocol_error_values[i].value)
            return mbim_protocol_error_values[i].value_nick;
    }

    return NULL;
}
static const GEnumValue mbim_status_error_values[] = {
    { MBIM_STATUS_ERROR_NONE, "MBIM_STATUS_ERROR_NONE", "None" },
    { MBIM_STATUS_ERROR_BUSY, "MBIM_STATUS_ERROR_BUSY", "Busy" },
    { MBIM_STATUS_ERROR_FAILURE, "MBIM_STATUS_ERROR_FAILURE", "Failure" },
    { MBIM_STATUS_ERROR_SIM_NOT_INSERTED, "MBIM_STATUS_ERROR_SIM_NOT_INSERTED", "SimNotInserted" },
    { MBIM_STATUS_ERROR_BAD_SIM, "MBIM_STATUS_ERROR_BAD_SIM", "BadSim" },
    { MBIM_STATUS_ERROR_PIN_REQUIRED, "MBIM_STATUS_ERROR_PIN_REQUIRED", "PinRequired" },
    { MBIM_STATUS_ERROR_PIN_DISABLED, "MBIM_STATUS_ERROR_PIN_DISABLED", "PinDisabled" },
    { MBIM_STATUS_ERROR_NOT_REGISTERED, "MBIM_STATUS_ERROR_NOT_REGISTERED", "NotRegistered" },
    { MBIM_STATUS_ERROR_PROVIDERS_NOT_FOUND, "MBIM_STATUS_ERROR_PROVIDERS_NOT_FOUND", "ProvidersNotFound" },
    { MBIM_STATUS_ERROR_NO_DEVICE_SUPPORT, "MBIM_STATUS_ERROR_NO_DEVICE_SUPPORT", "NoDeviceSupport" },
    { MBIM_STATUS_ERROR_PROVIDER_NOT_VISIBLE, "MBIM_STATUS_ERROR_PROVIDER_NOT_VISIBLE", "ProviderNotVisible" },
    { MBIM_STATUS_ERROR_DATA_CLASS_NOT_AVAILABLE, "MBIM_STATUS_ERROR_DATA_CLASS_NOT_AVAILABLE", "DataClassNotAvailable" },
    { MBIM_STATUS_ERROR_PACKET_SERVICE_DETACHED, "MBIM_STATUS_ERROR_PACKET_SERVICE_DETACHED", "PacketServiceDetached" },
    { MBIM_STATUS_ERROR_MAX_ACTIVATED_CONTEXTS, "MBIM_STATUS_ERROR_MAX_ACTIVATED_CONTEXTS", "MaxActivatedContexts" },
    { MBIM_STATUS_ERROR_NOT_INITIALIZED, "MBIM_STATUS_ERROR_NOT_INITIALIZED", "NotInitialized" },
    { MBIM_STATUS_ERROR_VOICE_CALL_IN_PROGRESS, "MBIM_STATUS_ERROR_VOICE_CALL_IN_PROGRESS", "VoiceCallInProgress" },
    { MBIM_STATUS_ERROR_CONTEXT_NOT_ACTIVATED, "MBIM_STATUS_ERROR_CONTEXT_NOT_ACTIVATED", "ContextNotActivated" },
    { MBIM_STATUS_ERROR_SERVICE_NOT_ACTIVATED, "MBIM_STATUS_ERROR_SERVICE_NOT_ACTIVATED", "ServiceNotActivated" },
    { MBIM_STATUS_ERROR_INVALID_ACCESS_STRING, "MBIM_STATUS_ERROR_INVALID_ACCESS_STRING", "InvalidAccessString" },
    { MBIM_STATUS_ERROR_INVALID_USER_NAME_PWD, "MBIM_STATUS_ERROR_INVALID_USER_NAME_PWD", "InvalidUserNamePwd" },
    { MBIM_STATUS_ERROR_RADIO_POWER_OFF, "MBIM_STATUS_ERROR_RADIO_POWER_OFF", "RadioPowerOff" },
    { MBIM_STATUS_ERROR_INVALID_PARAMETERS, "MBIM_STATUS_ERROR_INVALID_PARAMETERS", "InvalidParameters" },
    { MBIM_STATUS_ERROR_READ_FAILURE, "MBIM_STATUS_ERROR_READ_FAILURE", "ReadFailure" },
    { MBIM_STATUS_ERROR_WRITE_FAILURE, "MBIM_STATUS_ERROR_WRITE_FAILURE", "WriteFailure" },
    { MBIM_STATUS_ERROR_NO_PHONEBOOK, "MBIM_STATUS_ERROR_NO_PHONEBOOK", "NoPhonebook" },
    { MBIM_STATUS_ERROR_PARAMETER_TOO_LONG, "MBIM_STATUS_ERROR_PARAMETER_TOO_LONG", "ParameterTooLong" },
    { MBIM_STATUS_ERROR_STK_BUSY, "MBIM_STATUS_ERROR_STK_BUSY", "StkBusy" },
    { MBIM_STATUS_ERROR_OPERATION_NOT_ALLOWED, "MBIM_STATUS_ERROR_OPERATION_NOT_ALLOWED", "OperationNotAllowed" },
    { MBIM_STATUS_ERROR_MEMORY_FAILURE, "MBIM_STATUS_ERROR_MEMORY_FAILURE", "MemoryFailure" },
    { MBIM_STATUS_ERROR_INVALID_MEMORY_INDEX, "MBIM_STATUS_ERROR_INVALID_MEMORY_INDEX", "InvalidMemoryIndex" },
    { MBIM_STATUS_ERROR_MEMORY_FULL, "MBIM_STATUS_ERROR_MEMORY_FULL", "MemoryFull" },
    { MBIM_STATUS_ERROR_FILTER_NOT_SUPPORTED, "MBIM_STATUS_ERROR_FILTER_NOT_SUPPORTED", "FilterNotSupported" },
    { MBIM_STATUS_ERROR_DSS_INSTANCE_LIMIT, "MBIM_STATUS_ERROR_DSS_INSTANCE_LIMIT", "DssInstanceLimit" },
    { MBIM_STATUS_ERROR_INVALID_DEVICE_SERVICE_OPERATION, "MBIM_STATUS_ERROR_INVALID_DEVICE_SERVICE_OPERATION", "InvalidDeviceServiceOperation" },
    { MBIM_STATUS_ERROR_AUTH_INCORRECT_AUTN, "MBIM_STATUS_ERROR_AUTH_INCORRECT_AUTN", "AuthIncorrectAuth" },
    { MBIM_STATUS_ERROR_AUTH_SYNC_FAILURE, "MBIM_STATUS_ERROR_AUTH_SYNC_FAILURE", "AuthSyncFailure" },
    { MBIM_STATUS_ERROR_AUTH_AMF_NOT_SET, "MBIM_STATUS_ERROR_AUTH_AMF_NOT_SET", "AuthAmfNotSet" },
    { MBIM_STATUS_ERROR_CONTEXT_NOT_SUPPORTED, "MBIM_STATUS_ERROR_CONTEXT_NOT_SUPPORTED", "ContextNotSupported" },
    { MBIM_STATUS_ERROR_SMS_UNKNOWN_SMSC_ADDRESS, "MBIM_STATUS_ERROR_SMS_UNKNOWN_SMSC_ADDRESS", "SmsUnknownSmscAddress" },
    { MBIM_STATUS_ERROR_SMS_NETWORK_TIMEOUT, "MBIM_STATUS_ERROR_SMS_NETWORK_TIMEOUT", "SmsNetworkTimeout" },
    { MBIM_STATUS_ERROR_SMS_LANG_NOT_SUPPORTED, "MBIM_STATUS_ERROR_SMS_LANG_NOT_SUPPORTED", "SmsLangNotSupported" },
    { MBIM_STATUS_ERROR_SMS_ENCODING_NOT_SUPPORTED, "MBIM_STATUS_ERROR_SMS_ENCODING_NOT_SUPPORTED", "SmsEncodingNotSupported" },
    { MBIM_STATUS_ERROR_SMS_FORMAT_NOT_SUPPORTED, "MBIM_STATUS_ERROR_SMS_FORMAT_NOT_SUPPORTED", "SmsFormatNotSupported" },
    { MBIM_STATUS_ERROR_MS_NO_LOGICAL_CHANNELS, "MBIM_STATUS_ERROR_MS_NO_LOGICAL_CHANNELS", "NoLogicalChannels" },
    { MBIM_STATUS_ERROR_MS_SELECT_FAILED, "MBIM_STATUS_ERROR_MS_SELECT_FAILED", "SelectFailed" },
    { MBIM_STATUS_ERROR_MS_INVALID_LOGICAL_CHANNEL, "MBIM_STATUS_ERROR_MS_INVALID_LOGICAL_CHANNEL", "InvalidLogicalChannel" },
    { MBIM_STATUS_ERROR_INVALID_SIGNATURE, "MBIM_STATUS_ERROR_INVALID_SIGNATURE", "InvalidSignature" },
    { MBIM_STATUS_ERROR_INVALID_IMEI, "MBIM_STATUS_ERROR_INVALID_IMEI", "InvalidImei" },
    { MBIM_STATUS_ERROR_INVALID_TIMESTAMP, "MBIM_STATUS_ERROR_INVALID_TIMESTAMP", "InvalidTimeStamp" },
    { MBIM_STATUS_ERROR_NETWORK_LIST_TOO_LARGE, "MBIM_STATUS_ERROR_NETWORK_LIST_TOO_LARGE", "NetworkListTooLarge" },
    { MBIM_STATUS_ERROR_SIGNATURE_ALGORITHM_NOT_SUPPORTED, "MBIM_STATUS_ERROR_SIGNATURE_ALGORITHM_NOT_SUPPORTED", "SignatureAlgorithmNotSupported" },
    { MBIM_STATUS_ERROR_FEATURE_NOT_SUPPORTED, "MBIM_STATUS_ERROR_FEATURE_NOT_SUPPORTED", "FeatureNotSupported" },
    { MBIM_STATUS_ERROR_DECODE_OR_PARSING_ERROR, "MBIM_STATUS_ERROR_DECODE_OR_PARSING_ERROR", "DecodeOrParsingError" },
    { 0, NULL, NULL }
};

/* mbim_status_error_quark() implemented in mbim-errors-quarks.c */

GType
mbim_status_error_get_type (void)
{
    static gsize g_define_type_id_initialized = 0;

    if (g_once_init_enter (&g_define_type_id_initialized)) {
        GType g_define_type_id =
            g_enum_register_static (g_intern_static_string ("MbimStatusError"),
                                      mbim_status_error_values);
        g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

    return g_define_type_id_initialized;
}

/* Enum-specific method to get the value as a string.
 * We get the nick of the GEnumValue. Note that this will be
 * valid even if the GEnumClass is not referenced anywhere. */
/**
 * mbim_status_error_get_string:
 * @val: a MbimStatusError.
 *
 * Gets the nickname string for the #MbimStatusError specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *
mbim_status_error_get_string (MbimStatusError val)
{
    guint i;

    for (i = 0; mbim_status_error_values[i].value_nick; i++) {
        if ((gint)val == mbim_status_error_values[i].value)
            return mbim_status_error_values[i].value_nick;
    }

    return NULL;
}

/* Generated data ends here */

